CREATE TABLE IF NOT EXISTS `zp_classes` (
  `id` int(10) unsigned NOT NULL,
  `name` varchar(64) NOT NULL,
  `info` varchar(64) NOT NULL,
  `hp` int(10) unsigned NOT NULL,
  `speed` int(10) unsigned NOT NULL,
  `grav` decimal(5,2) NOT NULL,
  `kb` decimal(5,2) NOT NULL,
  UNIQUE KEY `id` (`id`)
)DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_class_stats` (
  `id` int(10) unsigned NOT NULL,
  `id_player` int(10) unsigned NOT NULL,
  `infect` int(10) unsigned NOT NULL default '0',
  `kills` int(10) unsigned NOT NULL default '0',
  `death` int(10) unsigned NOT NULL default '0',
  `games` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`,`id_player`)
)DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_graph` (
  `time` int(10) unsigned NOT NULL,
  `connections` int(2) unsigned NOT NULL,
  `kills` int(10) unsigned NOT NULL,
  `infects` int(10) unsigned NOT NULL,
  `damage` int(10) unsigned NOT NULL,
  PRIMARY KEY  (`time`)
)DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_maps` (
  `id` int(11) NOT NULL auto_increment,
  `map` varchar(32) NOT NULL,
  `zombie_win` int(11) NOT NULL default '0',
  `human_win` int(11) NOT NULL default '0',
  `tie` int(11) NOT NULL default '0',
  `games` int(11) NOT NULL default '1',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `map` (`map`)
) DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_players` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `ammo` int(10) unsigned NOT NULL default '0',
  `total_ammo` int(10) unsigned NOT NULL default '0',
  `nick` varchar(32) character set utf8 NOT NULL,
  `ip` varchar(32) character set utf8 NOT NULL,
  `steam_id` varchar(32) character set utf8 NOT NULL,
  `total_damage` int(10) unsigned NOT NULL default '0',
  `last_join` int(10) unsigned NOT NULL default '0',
  `last_leave` int(10) unsigned NOT NULL default '0',
  `first_zombie` int(11) NOT NULL default '0',
  `infect` int(11) NOT NULL default '0',
  `zombiekills` int(11) NOT NULL default '0',
  `humankills` int(11) NOT NULL default '0',
  `nemkills` int(11) NOT NULL default '0',
  `survkills` int(11) NOT NULL default '0',
  `suicide` int(11) NOT NULL default '0',
  `death` int(11) NOT NULL default '0',
  `infected` int(11) NOT NULL default '0',
  `online` int(11) NOT NULL default '0',
  `class` int(10) unsigned NOT NULL default '0',
  `nemesis` int(10) unsigned NOT NULL default '0',
  `survivor` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `nick` (`nick`,`ip`,`steam_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_server_players` (
  `id_player` int(10) unsigned NOT NULL,
  `server` varchar(25) NOT NULL,
  UNIQUE KEY `id_player` (`id_player`)
)DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_shoots` (
  `id_weapon` int(10) unsigned NOT NULL,
  `id_player` int(10) unsigned NOT NULL,
  `shoot` int(10) default '0',
  `hit_head` int(11) default '0',
  `hit_chest` int(11) NOT NULL default '0',
  `hit_stomach` int(11) NOT NULL default '0',
  `hit_leftarm` int(11) NOT NULL default '0',
  `hit_rightarm` int(11) NOT NULL default '0',
  `hit_leftleg` int(11) NOT NULL default '0',
  `hit_rightleg` int(11) NOT NULL default '0',
  `hit_shield` int(11) NOT NULL default '0',
  `kills` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id_player`,`id_weapon`)
)DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `zp_weapons` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `name` varchar(32) NOT NULL,
  PRIMARY KEY  (`id`)
) DEFAULT CHARSET=utf8;

INSERT INTO `zp_weapons` (`id`, `name`) VALUES
(1, 'P228'),
(3, 'SCOUT'),
(4, 'HEGRENADE'),
(5, 'XM1014'),
(6, 'C4'),
(7, 'MAC10'),
(8, 'AUG'),
(9, 'SMOKEGRENADE'),
(10, 'ELITE'),
(11, 'FIVESEVEN'),
(12, 'UMP45'),
(13, 'SG550'),
(14, 'GALIL'),
(15, 'FAMAS'),
(16, 'USP'),
(17, 'GLOCK18'),
(18, 'AWP'),
(19, 'MP5NAVY'),
(20, 'M249'),
(21, 'M3'),
(22, 'M4A1'),
(23, 'TMP'),
(24, 'G3SG1'),
(25, 'FLASHBANG'),
(26, 'DEAGLE'),
(27, 'SG552'),
(28, 'AK47'),
(29, 'KNIFE'),
(30, 'P90');

CREATE VIEW `zp_class_sum_stats` AS SELECT `zp_class_stats`.`id` AS `id`,SUM(`zp_class_stats`.`infect`) AS `infect`,SUM(`zp_class_stats`.`kills`) AS `kills`,SUM(`zp_class_stats`.`death`) AS `death`,SUM(`zp_class_stats`.`games`) AS `games` FROM `zp_class_stats` GROUP BY `zp_class_stats`.`id`;

CREATE VIEW `zp_weapon_stat` AS SELECT `zp_shoots`.`id_weapon` AS `id_weapon`,`zp_weapons`.`name` AS `name`,SUM(`zp_shoots`.`shoot`) AS `shoot`,SUM(`zp_shoots`.`hit_head`) AS `hit_head`,SUM(`zp_shoots`.`hit_chest`) AS `hit_chest`,SUM(`zp_shoots`.`hit_stomach`) AS `hit_stomach`,SUM(`zp_shoots`.`hit_leftarm`) AS `hit_leftarm`,SUM(`zp_shoots`.`hit_rightarm`) AS `hit_rightarm`,SUM(`zp_shoots`.`hit_leftleg`) AS `hit_leftleg`,SUM(`zp_shoots`.`hit_rightleg`) AS `hit_rightleg`,SUM(`zp_shoots`.`kills`) AS `kills` FROM (`zp_shoots` JOIN `zp_weapons`) WHERE (`zp_shoots`.`id_weapon` = `zp_weapons`.`id`) GROUP BY `zp_shoots`.`id_weapon`;
